#TODO list

1. Write a `calculate_molecular_weight()` method
2. Remove the dependencies in the installation setup.py as they are not working properly (or fix them :))
3. tests  tests/test_suggestions.py is not finding roles.txt and reaction_list.txt


